translate.convert.ts2po.ts2po

Package translate :: Package convert :: Module ts2po :: Class ts2po |
[hide private]
[frames] | no frames]

# Class ts2po

source code

Instance Methods | [hide private]
__init__(self, duplicatestyle="msgctxt") | source code
convertmessage(self, contextname, messagenum, source, target, msgcomments, transtype) makes a pounit from the given message | source code
convertfile(self, inputfile) converts a .ts file to .po format | source code